@@ -1,6 +1,6 @@
 
 #include "soundkonverter.h"
-#include "config.h"
+#include "configuration.h"
 #include "configdialog.h"
 #include "logger.h"
 #include "logviewer.h"
@@ -19,20 +19,20 @@
 #include "optionsrequester.h"
 #include "dirdialog.h"
 
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kinputdialog.h>
 #include <kpushbutton.h>
-#include <kpopupmenu.h>
-//#include <kmenubar.h>
-#include <kaction.h>
+#include <tdepopupmenu.h>
+//#include <tdemenubar.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
 #include <kedittoolbar.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstddirs.h>
-#include <kio/job.h>
+#include <tdeio/job.h>
 #include <kprocess.h>
 #include <ksystemtray.h>
 
@@ -47,7 +47,7 @@
 // ### soundkonverter 0.4: save file list when kde session gets terminated
 
 soundKonverter::soundKonverter()
-    : KMainWindow( 0, "soundkonverter-mainwindow", WType_TopLevel | WDestructiveClose | WStyle_ContextHelp ),
+    : TDEMainWindow( 0, "soundkonverter-mainwindow", WType_TopLevel | WDestructiveClose | WStyle_ContextHelp ),
       DCOPObject( "soundkonverter-app" )
 {
     // this is our first startup, set instances to zero
@@ -75,20 +75,20 @@ soundKonverter::soundKonverter()
 
     // (re)move the 0.2 config file
     if( config->data.app.configVersion < 280 ) {
-        KIO::rename( locateLocal("config","soundkonverterrc"), locateLocal("config","soundkonverterrc.back"), true );
+        TDEIO::rename( locateLocal("config","soundkonverterrc"), locateLocal("config","soundkonverterrc.back"), true );
 //         KMessageBox::information( this, "You are using a pre-release of soundKonverter. This version is designed for testing only.\nThere are a few things not implemented at the moment but it should run without crashes and big problems. So feel free to report such an error if you find one.\nPlease have a look at the README.\n\nYour old configuration file has been moved to soundkonverterrc.back." );
     }
 //     if( config->data.app.configVersion < 290 ) {
 //         TQFile plugin_dir( locateLocal("data","soundkonverter/plugins") );
 //         if( plugin_dir.exists() ) {
-//             KIO::rename( locateLocal("data","soundkonverter/plugins"), locateLocal("data","soundkonverter/plugins.back"), true );
+//             TDEIO::rename( locateLocal("data","soundkonverter/plugins"), locateLocal("data","soundkonverter/plugins.back"), true );
 //             int ret = KMessageBox::questionYesNo( this, i18n("soundKonverter has cleaned up it's old installation. It seems to be necessary to restart soundKonverter!\n\nDo you want to restart soundKonverter now?") );
 //             if( ret == KMessageBox::Yes ) {
 //                 config->write();
 //                 // TODO parameters are lost
-//                 KProcess restart;
+//                 TDEProcess restart;
 //                 restart << "soundkonverter";
-//                 restart.start( KProcess::DontCare );
+//                 restart.start( TDEProcess::DontCare );
 //                 kapp->quit();
 //                 return;
 //             }
@@ -104,7 +104,7 @@ soundKonverter::soundKonverter()
     systemTray->hide();
 
     // create an icon loader object for loading icons
-    KIconLoader *iconLoader = new KIconLoader();
+    TDEIconLoader *iconLoader = new TDEIconLoader();
 
     TQWidget* widget = new TQWidget( this, "widget" );
     setCentralWidget( widget );
@@ -113,36 +113,36 @@ soundKonverter::soundKonverter()
     options = new Options( config, i18n("Choose your prefered output options and click on \"Add files ...\"!"), widget, "options" );
     fileList = new FileList( cdManager, tagEngine, config, options, logger, widget, "fileList" );
 
-    startAction = new KAction( i18n("&Start conversion"), "run", 0, TQT_TQOBJECT(fileList), TQT_SLOT(startConversion()), actionCollection(), "start" );
+    startAction = new TDEAction( i18n("&Start conversion"), "system-run", 0, fileList, TQ_SLOT(startConversion()), actionCollection(), "start" );
     startAction->setEnabled( false );
-    new KAction( i18n("&Replay Gain Tool ..."), "soundkonverter_replaygain", CTRL+Key_R, TQT_TQOBJECT(this), TQT_SLOT(showReplayGainScanner()), actionCollection(), "replaygainscanner" );
-    //new KAction( i18n("R&epair Tool ..."), "soundkonverter_repair", CTRL+Key_E, TQT_TQOBJECT(this), TQT_SLOT(showRepairTool()), actionCollection(), "repairtool" );
-    new KAction( i18n("C&uesheet Editor ..."), "kwrite", CTRL+Key_U, TQT_TQOBJECT(this), TQT_SLOT(showCuesheetEditor()), actionCollection(), "cuesheeteditor" );
-    new KAction( i18n("Show &Log ..."), "view_text", CTRL+Key_L, TQT_TQOBJECT(this), TQT_SLOT(showLogViewer()), actionCollection(), "log" );
-//     new KAction( i18n("About &Plugins ..."), "connect_creating", CTRL+Key_P, TQT_TQOBJECT(this), TQT_SLOT(showAboutPlugins()), actionCollection(), "about_plugins" );
+    new TDEAction( i18n("&Replay Gain Tool ..."), "soundkonverter_replaygain", CTRL+Key_R, this, TQ_SLOT(showReplayGainScanner()), actionCollection(), "replaygainscanner" );
+    //new TDEAction( i18n("R&epair Tool ..."), "soundkonverter_repair", CTRL+Key_E, this, TQ_SLOT(showRepairTool()), actionCollection(), "repairtool" );
+    new TDEAction( i18n("C&uesheet Editor ..."), "kwrite", CTRL+Key_U, this, TQ_SLOT(showCuesheetEditor()), actionCollection(), "cuesheeteditor" );
+    new TDEAction( i18n("Show &Log ..."), "view_text", CTRL+Key_L, this, TQ_SLOT(showLogViewer()), actionCollection(), "log" );
+//     new TDEAction( i18n("About &Plugins ..."), "connect_creating", CTRL+Key_P, this, TQ_SLOT(showAboutPlugins()), actionCollection(), "about_plugins" );
 
-    stopAction = new KAction( i18n("S&top after current file is complete"), "stop", CTRL+Key_O, TQT_TQOBJECT(fileList), TQT_SLOT(stopConversion()), actionCollection(), "stop" );
-    continueAction = new KAction( i18n("&Continue after current file is complete"), "run", CTRL+Key_T, TQT_TQOBJECT(fileList), TQT_SLOT(continueConversion()), actionCollection(), "continue" );
-    killAction = new KAction( i18n("Stop &immediately"), "exit", CTRL+Key_K, TQT_TQOBJECT(fileList), TQT_SLOT(killConversion()), actionCollection(), "kill" );
-    stopActionMenu = new KActionMenu( i18n("Stop"), "stop", actionCollection(), "stopMenu" );
+    stopAction = new TDEAction( i18n("S&top after current file is complete"), "process-stop", CTRL+Key_O, fileList, TQ_SLOT(stopConversion()), actionCollection(), "stop" );
+    continueAction = new TDEAction( i18n("&Continue after current file is complete"), "system-run", CTRL+Key_T, fileList, TQ_SLOT(continueConversion()), actionCollection(), "continue" );
+    killAction = new TDEAction( i18n("Stop &immediately"), "system-log-out", CTRL+Key_K, fileList, TQ_SLOT(killConversion()), actionCollection(), "kill" );
+    stopActionMenu = new TDEActionMenu( i18n("Stop"), "process-stop", actionCollection(), "stopMenu" );
     stopActionMenu->setDelayed( false );
     stopActionMenu->setEnabled( false );
 //     stopActionMenu->insert( stopAction );
 //     stopActionMenu->insert( continueAction );
 //     stopActionMenu->insert( killAction );
 
-/*    veryHighPriorityAction = new KToggleAction( i18n("Very hi&gh"), CTRL+Key_1, TQT_TQOBJECT(this), TQT_SLOT(priorityChanged()), actionCollection(), "veryhigh" );
+/*    veryHighPriorityAction = new TDEToggleAction( i18n("Very hi&gh"), CTRL+Key_1, this, TQ_SLOT(priorityChanged()), actionCollection(), "veryhigh" );
     veryHighPriorityAction->setExclusiveGroup("priorityActionMenu");
-    highPriorityAction = new KToggleAction( i18n("&High"), CTRL+Key_2, TQT_TQOBJECT(this), TQT_SLOT(priorityChanged()), actionCollection(), "high" );
+    highPriorityAction = new TDEToggleAction( i18n("&High"), CTRL+Key_2, this, TQ_SLOT(priorityChanged()), actionCollection(), "high" );
     highPriorityAction->setExclusiveGroup("priorityActionMenu");
-    normalPriorityAction = new KToggleAction( i18n("&Normal"), CTRL+Key_3, TQT_TQOBJECT(this), TQT_SLOT(priorityChanged()), actionCollection(), "nomal" );
+    normalPriorityAction = new TDEToggleAction( i18n("&Normal"), CTRL+Key_3, this, TQ_SLOT(priorityChanged()), actionCollection(), "nomal" );
     normalPriorityAction->setExclusiveGroup("priorityActionMenu");
     normalPriorityAction->setChecked(true);
-    lowPriorityAction = new KToggleAction( i18n("&Low"), CTRL+Key_4, TQT_TQOBJECT(this), TQT_SLOT(priorityChanged()), actionCollection(), "low" );
+    lowPriorityAction = new TDEToggleAction( i18n("&Low"), CTRL+Key_4, this, TQ_SLOT(priorityChanged()), actionCollection(), "low" );
     lowPriorityAction->setExclusiveGroup("priorityActionMenu");
-    veryLowPriorityAction = new KToggleAction( i18n("Very lo&w"), CTRL+Key_5, TQT_TQOBJECT(this), TQT_SLOT(priorityChanged()), actionCollection(), "verylow" );
+    veryLowPriorityAction = new TDEToggleAction( i18n("Very lo&w"), CTRL+Key_5, this, TQ_SLOT(priorityChanged()), actionCollection(), "verylow" );
     veryLowPriorityAction->setExclusiveGroup("priorityActionMenu");
-    priorityActionMenu = new KActionMenu( i18n("En-/Decoder priority"), "ksysguard", actionCollection(), "priorityMenu" );
+    priorityActionMenu = new TDEActionMenu( i18n("En-/Decoder priority"), "ksysguard", actionCollection(), "priorityMenu" );
     priorityActionMenu->setDelayed( false );
     priorityActionMenu->insert(veryHighPriorityAction);
     priorityActionMenu->insert(highPriorityAction);
@@ -151,22 +151,22 @@ soundKonverter::soundKonverter()
     priorityActionMenu->insert(veryLowPriorityAction);*/
     //priorityChanged();
 
-    new KAction( i18n("A&dd Files ..."), "sound", CTRL+Key_D, TQT_TQOBJECT(this), TQT_SLOT(showFileDialog()), actionCollection(), "add_files" );
-    new KAction( i18n("Add &Folder ..."), "folder", CTRL+Key_F, TQT_TQOBJECT(this), TQT_SLOT(showDirDialog()), actionCollection(), "add_folder" );
-    new KAction( i18n("Add CD &tracks ..."), "cdaudio_unmount", CTRL+Key_T, TQT_TQOBJECT(this), TQT_SLOT(showCdDialog()), actionCollection(), "add_audiocd" );
-    new KAction( i18n("Add &URL ..."), "browser", CTRL+Key_U, TQT_TQOBJECT(this), TQT_SLOT(showUrlDialog()), actionCollection(), "add_url" );
-    KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
+    new TDEAction( i18n("A&dd Files ..."), "audio-x-generic", CTRL+Key_D, this, TQ_SLOT(showFileDialog()), actionCollection(), "add_files" );
+    new TDEAction( i18n("Add &Folder ..."), "audio-x-generic", CTRL+Key_F, this, TQ_SLOT(showDirDialog()), actionCollection(), "add_folder" );
+    new TDEAction( i18n("Add CD &tracks ..."), "media-optical-cdaudio-unmounted", CTRL+Key_T, this, TQ_SLOT(showCdDialog()), actionCollection(), "add_audiocd" );
+    new TDEAction( i18n("Add &URL ..."), "browser", CTRL+Key_U, this, TQ_SLOT(showUrlDialog()), actionCollection(), "add_url" );
+    KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
 
-    new KAction( i18n("L&oad file list"), "fileopen", 0, TQT_TQOBJECT(fileList), TQT_SLOT(load()), actionCollection(), "load" );
-    new KAction( i18n("Sa&ve file list"), "filesave", 0, TQT_TQOBJECT(fileList), TQT_SLOT(save()), actionCollection(), "save" );
+    new TDEAction( i18n("L&oad file list"), "document-open", 0, fileList, TQ_SLOT(load()), actionCollection(), "load" );
+    new TDEAction( i18n("Sa&ve file list"), "document-save", 0, fileList, TQ_SLOT(save()), actionCollection(), "save" );
 
-    // TODO //KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT(pasteFiles()), actionCollection() );
+    // TODO //KStdAction::paste( this, TQ_SLOT(pasteFiles()), actionCollection() );
 
-    KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT(showConfigDialog()), actionCollection() );
+    KStdAction::preferences( this, TQ_SLOT(showConfigDialog()), actionCollection() );
 
-    showToolBarAction = KStdAction::showToolbar( TQT_TQOBJECT(this), TQT_SLOT(showToolbar()), actionCollection() );
+    showToolBarAction = KStdAction::showToolbar( this, TQ_SLOT(showToolbar()), actionCollection() );
     //KStdAction::showStatusbar( 0, 0, actionCollection() );
-    KStdAction::configureToolbars( TQT_TQOBJECT(this), TQT_SLOT(editToolbar()), actionCollection() );
+    KStdAction::configureToolbars( this, TQ_SLOT(editToolbar()), actionCollection() );
 
     createGUI();
 
@@ -185,11 +185,11 @@ soundKonverter::soundKonverter()
     // generate the options input area
     // NOTE created above because of some dependences
     //options = new Options( config, i18n("Choose your prefered output options and click on \"Add files ...\"!"), this, "options" );
-    connect( options, TQT_SIGNAL(showConfigPluginsPage()),
-               TQT_TQOBJECT(this), TQT_SLOT(showConfigPluginsPage())
+    connect( options, TQ_SIGNAL(showConfigPluginsPage()),
+               this, TQ_SLOT(showConfigPluginsPage())
              );
-    connect( options, TQT_SIGNAL(showConfigEnvironmentPage()),
-               TQT_TQOBJECT(this), TQT_SLOT(showConfigEnvironmentPage())
+    connect( options, TQ_SIGNAL(showConfigEnvironmentPage()),
+               this, TQ_SLOT(showConfigEnvironmentPage())
              );
     gridLayout->addWidget( options, 0, 0 );
 
@@ -198,28 +198,28 @@ soundKonverter::soundKonverter()
     //fileList = new FileList( cdManager, tagEngine, config, options, this, "fileList" );
     gridLayout->addWidget( fileList, 1, 0 );
     gridLayout->setRowStretch( 1, 1 );
-    /*connect( TQT_TQOBJECT(this), TQT_SIGNAL(windowMoved(int,int)),
-               TQT_TQOBJECT(fileList), TQT_SLOT(moveOptionsEditor(int,int))
+    /*connect( this, TQ_SIGNAL(windowMoved(int,int)),
+               fileList, TQ_SLOT(moveOptionsEditor(int,int))
              );*/
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(fileCountChanged(int)),
-               TQT_TQOBJECT(this), TQT_SLOT(fileCountChanged(int))
+    connect( fileList, TQ_SIGNAL(fileCountChanged(int)),
+               this, TQ_SLOT(fileCountChanged(int))
              );
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(startedConversion()),
-               TQT_TQOBJECT(this), TQT_SLOT(startedConversion())
+    connect( fileList, TQ_SIGNAL(startedConversion()),
+               this, TQ_SLOT(startedConversion())
              );
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(stopClicked()),
-               TQT_TQOBJECT(this), TQT_SLOT(stopClicked())
+    connect( fileList, TQ_SIGNAL(stopClicked()),
+               this, TQ_SLOT(stopClicked())
              );
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(continueClicked()),
-               TQT_TQOBJECT(this), TQT_SLOT(continueClicked())
+    connect( fileList, TQ_SIGNAL(continueClicked()),
+               this, TQ_SLOT(continueClicked())
              );
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(stoppedConversion()),
-               TQT_TQOBJECT(this), TQT_SLOT(stoppedConversion())
+    connect( fileList, TQ_SIGNAL(stoppedConversion()),
+               this, TQ_SLOT(stoppedConversion())
              );
 
     convert = new Convert( config, tagEngine, cdManager, fileList, logger );
-//     connect( TQT_TQOBJECT(this), TQT_SIGNAL(setPriority(int)),
-//                convert, TQT_SLOT(priorityChanged(int))
+//     connect( this, TQ_SIGNAL(setPriority(int)),
+//                convert, TQ_SLOT(priorityChanged(int))
 //              );
 
     // add a horizontal box layout for the add combobutton to the grid
@@ -232,26 +232,26 @@ soundKonverter::soundKonverter()
     //font.setWeight( TQFont::DemiBold );
     font.setPointSize( font.pointSize() + 1 );
     cAdd->setFont( font );
-    cAdd->insertItem( iconLoader->loadIcon("sound",KIcon::Toolbar), i18n("Add files ...") );
-    cAdd->insertItem( iconLoader->loadIcon("folder",KIcon::Toolbar), i18n("Add folder ...") );
-    cAdd->insertItem( iconLoader->loadIcon("cdaudio_unmount",KIcon::Toolbar), i18n("Add CD tracks ...") );
-    cAdd->insertItem( iconLoader->loadIcon("browser",KIcon::Toolbar), i18n("Add URL ...") );
+    cAdd->insertItem( iconLoader->loadIcon("audio-x-generic",TDEIcon::Toolbar), i18n("Add files ...") );
+    cAdd->insertItem( iconLoader->loadIcon("folder",TDEIcon::Toolbar), i18n("Add folder ...") );
+    cAdd->insertItem( iconLoader->loadIcon("media-optical-cdaudio-unmounted",TDEIcon::Toolbar), i18n("Add CD tracks ...") );
+    cAdd->insertItem( iconLoader->loadIcon("browser",TDEIcon::Toolbar), i18n("Add URL ...") );
     addBox->addWidget( cAdd );
-    connect( cAdd, TQT_SIGNAL(clicked(int)),
-             TQT_TQOBJECT(this), TQT_SLOT(addClicked(int))
+    connect( cAdd, TQ_SIGNAL(clicked(int)),
+             this, TQ_SLOT(addClicked(int))
            );
 
     addBox->addSpacing( 18 );
 
-    pStart = new KPushButton( iconLoader->loadIcon("run",KIcon::Small), i18n("Start"), widget, "pStart" );
+    pStart = new KPushButton( iconLoader->loadIcon("system-run",TDEIcon::Small), i18n("Start"), widget, "pStart" );
     pStart->setFixedHeight( pStart->size().height() );
     pStart->setEnabled( false );
     addBox->addWidget( pStart );
-    connect( pStart, TQT_SIGNAL(clicked()),
-               TQT_TQOBJECT(fileList), TQT_SLOT(startConversion())
+    connect( pStart, TQ_SIGNAL(clicked()),
+               fileList, TQ_SLOT(startConversion())
              );
 
-    pStop = new KPushButton( iconLoader->loadIcon("stop",KIcon::Small), i18n("Stop"), widget, "pStop" );
+    pStop = new KPushButton( iconLoader->loadIcon("process-stop",TDEIcon::Small), i18n("Stop"), widget, "pStop" );
     pStop->setFixedHeight( pStop->size().height() );
     pStop->hide();
     pStop->setPopup( stopActionMenu->popupMenu() );
@@ -261,29 +261,29 @@ soundKonverter::soundKonverter()
 
     progressIndicator = new ProgressIndicator( systemTray, widget, "progressIndicator" );
     addBox->addWidget( progressIndicator );
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(increaseTime(float)),
-               progressIndicator, TQT_SLOT(increaseTime(float))
+    connect( fileList, TQ_SIGNAL(increaseTime(float)),
+               progressIndicator, TQ_SLOT(increaseTime(float))
              );
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(decreaseTime(float)),
-               progressIndicator, TQT_SLOT(decreaseTime(float))
+    connect( fileList, TQ_SIGNAL(decreaseTime(float)),
+               progressIndicator, TQ_SLOT(decreaseTime(float))
              );
-    /*connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(setTime(float)),
-               progressIndicator, TQT_SLOT(setTime(float))
+    /*connect( fileList, TQ_SIGNAL(setTime(float)),
+               progressIndicator, TQ_SLOT(setTime(float))
              );*/
-    connect( TQT_TQOBJECT(fileList), TQT_SIGNAL(finished(float)),
-               progressIndicator, TQT_SLOT(finished(float))
+    connect( fileList, TQ_SIGNAL(finished(float)),
+               progressIndicator, TQ_SLOT(finished(float))
              );
-    connect( convert, TQT_SIGNAL(countTime(float)),
-               progressIndicator, TQT_SLOT(countTime(float))
+    connect( convert, TQ_SIGNAL(countTime(float)),
+               progressIndicator, TQ_SLOT(countTime(float))
              );
-    connect( convert, TQT_SIGNAL(uncountTime(float)),
-               progressIndicator, TQT_SLOT(uncountTime(float))
+    connect( convert, TQ_SIGNAL(uncountTime(float)),
+               progressIndicator, TQ_SLOT(uncountTime(float))
              );
-    connect( convert, TQT_SIGNAL(update(float)),
-               progressIndicator, TQT_SLOT(update(float))
+    connect( convert, TQ_SIGNAL(update(float)),
+               progressIndicator, TQ_SLOT(update(float))
              );
-    connect( progressIndicator, TQT_SIGNAL(setTitle(const TQString&)),
-               TQT_TQOBJECT(this), TQT_SLOT(setTitle(const TQString&))
+    connect( progressIndicator, TQ_SIGNAL(setTitle(const TQString&)),
+               this, TQ_SLOT(setTitle(const TQString&))
              );
 
     cAdd->increaseHeight( /*progressIndicator->height() - cAdd->height()*/ 10 ); // FIXME detect the height automaticly
@@ -340,14 +340,14 @@ void soundKonverter::openArgFiles( const TQStringList &files )
     {
         OptionsRequester* dialog = new OptionsRequester( config, files, this );
 
-        connect( dialog, TQT_SIGNAL(setCurrentOptions(const ConversionOptions&)),
-                   options, TQT_SLOT(setCurrentOptions(const ConversionOptions&))
+        connect( dialog, TQ_SIGNAL(setCurrentOptions(const ConversionOptions&)),
+                   options, TQ_SLOT(setCurrentOptions(const ConversionOptions&))
                  );
-        connect( dialog, TQT_SIGNAL(addFiles(TQStringList)),
-                   TQT_TQOBJECT(fileList), TQT_SLOT(addFiles(TQStringList))
+        connect( dialog, TQ_SIGNAL(addFiles(TQStringList)),
+                   fileList, TQ_SLOT(addFiles(TQStringList))
                  );
 
-        Q_CHECK_PTR( dialog );
+        TQ_CHECK_PTR( dialog );
 
         if( profile != "" ) {
             dialog->setProfile( profile );
@@ -364,8 +364,8 @@ void soundKonverter::openArgFiles( const TQStringList &files )
 
         dialog->exec();
 
-        disconnect( dialog, TQT_SIGNAL(setCurrentOptions(const ConversionOptions&)), 0, 0 );
-        disconnect( dialog, TQT_SIGNAL(addFiles(TQStringList)), 0, 0 );
+        disconnect( dialog, TQ_SIGNAL(setCurrentOptions(const ConversionOptions&)), 0, 0 );
+        disconnect( dialog, TQ_SIGNAL(addFiles(TQStringList)), 0, 0 );
 
         delete dialog;
     }
@@ -511,7 +511,7 @@ void soundKonverter::showDirDialog()
 
     DirDialog *dialog = new DirDialog( config, DirDialog::Convert, this, "DirDialog" );
 
-    Q_CHECK_PTR( dialog );
+    TQ_CHECK_PTR( dialog );
 
     if( dialog->exec() ) {
         fileList->addDir( dialog->directory, dialog->selectedFileTypes, dialog->recursive );
@@ -528,14 +528,14 @@ void soundKonverter::showCdDialog( bool intern )
     {
         OptionsRequester* dialog = new OptionsRequester( config, "", this );
 
-        connect( dialog, TQT_SIGNAL(setCurrentOptions(const ConversionOptions&)),
-                   options, TQT_SLOT(setCurrentOptions(const ConversionOptions&))
+        connect( dialog, TQ_SIGNAL(setCurrentOptions(const ConversionOptions&)),
+                   options, TQ_SLOT(setCurrentOptions(const ConversionOptions&))
                  );
-//         connect( dialog, TQT_SIGNAL(addFiles(TQStringList)),
-//                    TQT_TQOBJECT(fileList), TQT_SLOT(addFiles(TQStringList))
+//         connect( dialog, TQ_SIGNAL(addFiles(TQStringList)),
+//                    fileList, TQ_SLOT(addFiles(TQStringList))
 //                  );
 
-        Q_CHECK_PTR( dialog );
+        TQ_CHECK_PTR( dialog );
 
         if( profile != "" ) {
             dialog->setProfile( profile );
@@ -552,8 +552,8 @@ void soundKonverter::showCdDialog( bool intern )
 
         dialog->exec();
 
-        disconnect( dialog, TQT_SIGNAL(setCurrentOptions(const ConversionOptions&)), 0, 0 );
-//         disconnect( dialog, TQT_SIGNAL(addFiles(TQStringList)), 0, 0 );
+        disconnect( dialog, TQ_SIGNAL(setCurrentOptions(const ConversionOptions&)), 0, 0 );
+//         disconnect( dialog, TQ_SIGNAL(addFiles(TQStringList)), 0, 0 );
 
         delete dialog;
     }
@@ -590,25 +590,25 @@ void soundKonverter::showCdDialog( bool intern )
 
     device = "";
 
-    Q_CHECK_PTR( dialog );
+    TQ_CHECK_PTR( dialog );
 
     if( !dialog->noCD )
     {
-        connect( dialog, TQT_SIGNAL(addTracks(const TQString&,TQValueList<int>)),
-                TQT_TQOBJECT(fileList), TQT_SLOT(addTracks(const TQString&,TQValueList<int>))
+        connect( dialog, TQ_SIGNAL(addTracks(const TQString&,TQValueList<int>)),
+                fileList, TQ_SLOT(addTracks(const TQString&,TQValueList<int>))
                 );
-        connect( dialog, TQT_SIGNAL(addDisc(const TQString&)),
-                TQT_TQOBJECT(fileList), TQT_SLOT(addDisc(const TQString&))
+        connect( dialog, TQ_SIGNAL(addDisc(const TQString&)),
+                fileList, TQ_SLOT(addDisc(const TQString&))
                 );
-        /*connect( dialog, TQT_SIGNAL(openCuesheetEditor(const TQString&)),
-                TQT_TQOBJECT(this), TQT_SLOT(openCuesheetEditor(const TQString&))
+        /*connect( dialog, TQ_SIGNAL(openCuesheetEditor(const TQString&)),
+                this, TQ_SLOT(openCuesheetEditor(const TQString&))
                 );*/
 
         dialog->exec();
 
-        disconnect( dialog, TQT_SIGNAL(addTracks(const TQString&,TQValueList<int>)), 0, 0 );
-        disconnect( dialog, TQT_SIGNAL(addDisc(const TQString&)), 0, 0 );
-        //disconnect( dialog, TQT_SIGNAL(openCuesheetEditor(const TQString&)), 0, 0 );
+        disconnect( dialog, TQ_SIGNAL(addTracks(const TQString&,TQValueList<int>)), 0, 0 );
+        disconnect( dialog, TQ_SIGNAL(addDisc(const TQString&)), 0, 0 );
+        //disconnect( dialog, TQ_SIGNAL(openCuesheetEditor(const TQString&)), 0, 0 );
     }
     delete dialog;
 
@@ -639,8 +639,8 @@ void soundKonverter::showReplayGainScanner()
             // TODO error message
             return;
         }
-//         connect( TQT_TQOBJECT(this), TQT_SIGNAL(addFilesToReplayGainScanner(TQStringList)),
-//                    replayGainScanner, TQT_SLOT(addFiles(TQStringList))
+//         connect( this, TQ_SIGNAL(addFilesToReplayGainScanner(TQStringList)),
+//                    replayGainScanner, TQ_SLOT(addFiles(TQStringList))
 //                  );
     }
     replayGainScanner->show();
@@ -684,8 +684,8 @@ void soundKonverter::showLogViewer()
             // TODO error message
             return;
         }
-//         connect( convert, TQT_SIGNAL(finishedProcess(int,int)),
-//                    logViewer, TQT_SLOT(processCompleted(int,int))
+//         connect( convert, TQ_SIGNAL(finishedProcess(int,int)),
+//                    logViewer, TQ_SLOT(processCompleted(int,int))
 //                  );
     }
     logViewer->show();
@@ -696,7 +696,7 @@ void soundKonverter::showConfigDialog()
 {
     ConfigDialog *dialog = new ConfigDialog( config, this, "ConfigDialog", ConfigDialog::Page(configStartPage) );
 
-    Q_CHECK_PTR( dialog );
+    TQ_CHECK_PTR( dialog );
 
     //dialog->setGeometry( frameGeometry() );
     dialog->resize( size() );
@@ -724,7 +724,7 @@ void soundKonverter::showConfigEnvironmentPage()
 // {
 //     AboutPlugins *dialog = new AboutPlugins( config, this, "AboutPlugins" );
 // 
-//     Q_CHECK_PTR( dialog );
+//     TQ_CHECK_PTR( dialog );
 // 
 //     dialog->exec();
 // 
@@ -747,8 +747,8 @@ void soundKonverter::editToolbar()
 {
     saveMainWindowSettings( kapp->config(), "MainWindow" );
     KEditToolbar dlg( actionCollection() );
-    connect( &dlg, TQT_SIGNAL(newToolbarConfig()),
-               TQT_TQOBJECT(this), TQT_SLOT(newToolbarConfig())
+    connect( &dlg, TQ_SIGNAL(newToolbarConfig()),
+               this, TQ_SLOT(newToolbarConfig())
              );
     dlg.exec();
 }
